@@ -1,11 +1,13 @@
 from .version import __version__
 import click
-import importlib, importlib.util
+import importlib
+import importlib.util
 import logging
 from os.path import dirname, basename, join
 from glob import glob
 from .commands.record import record
 from .commands.subset import subset
+from .commands.split_subset import split_subset
 from .commands.verify import verify
 from .utils import logger
 
@@ -23,7 +25,7 @@ from .utils import logger
     '--plugins',
     'plugin_dir',
     help='Directory to load plugins from',
-    type = click.Path(exists=True, file_okay=False)
+    type=click.Path(exists=True, file_okay=False)
 )
 def main(log_level, plugin_dir):
     level = logger.get_log_level(log_level)
@@ -39,12 +41,15 @@ def main(log_level, plugin_dir):
     # load all plugins
     if plugin_dir:
         for f in glob(join(plugin_dir, '*.py')):
-            spec = importlib.util.spec_from_file_location("launchable.plugins.{}".format(basename(f)[:-3]), f)
+            spec = importlib.util.spec_from_file_location(
+                "launchable.plugins.{}".format(basename(f)[:-3]), f)
             plugin = importlib.util.module_from_spec(spec)
             spec.loader.exec_module(plugin)
 
+
 main.add_command(record)
 main.add_command(subset)
+main.add_command(split_subset)
 main.add_command(verify)
 
 
